#include <msp430.h>
#include "function.h"

#define TA32HZPERIOD (512)
#define TBPERIOD	(0x0F)
#define TBDUTY		(0x07)

unsigned int adc_result;

/*
 * main.c
 */
int main(void) {
    WDTCTL = WDTPW | WDTHOLD;	// Stop watchdog timer

    /* podesavanje LED displeja */
    P6DIR |= ~BIT7;				// segmenti
    P11DIR |= BIT1;				// selektovan prvi displej
    P11OUT &= ~BIT1;			// ukljucen prvi displej

    /* podesavanje A/D konvertora */
    P7SEL |= BIT6;				// selektovan A/D kanal A14
    ADC12CTL0 = ADC12ON;		// ukljucen ADC12
    ADC12CTL1 = ADC12SHS_1 + ADC12CONSEQ_2;	// sample/hold vreme diktira SHS signal
    ADC12MCTL0 = ADC12INCH_14;	// vrsi se akvizicija kanala 14
    ADC12IE |= ADC12IE0;		// dozvola prekida po zavrsenoj konverziji
    ADC12CTL0 |= ADC12ENC;		// dozvola konverzija

    /* podesavanje tajmera za A/D */
    TA0CCTL0 = OUTMOD_4;		// outmod = toggle
    TA0CCR0 = TA32HZPERIOD;		// 32Hz
    TA0CTL = TASSEL_1 + MC_1;	// ACLK, up mode

    /* podesavanje PWM-a za diodu */
    P4DIR |= BIT3;				// seletovana dioda
    P4SEL |= BIT3;				// tajmer upravlja diodom
    TB0CCR0 = TBPERIOD;			// PWM period
    TB0CCTL3 = OUTMOD_7;		// CCR3 reset/set
    TB0CCR3 = TBDUTY;			// CCR3 PWM duty cycle
    TB0CTL = TBSSEL_1 + MC_1;	// ACLK, up mode

    __bis_SR_register(GIE);		// globalna dozvola maskirajucih prekida

    /* glavna petlja */
    while (1);
}

/*
 * ADC12 prekidna rutina
 */
void __attribute__((interrupt(ADC12_VECTOR))) adc12isr()
__interrupt void ADC12_ISR(void)
{
	switch (ADC12IV)
	{
	case  0: break;				// Vector  0: No interrupt
	case  2: break;				// Vector  2: ADC overflow
	case  4: break;				// Vector  4: ADC timing overflow
	case  6:					// Vector  6: ADC12IFG0
		adc_result = ADC12MEM0;		// ocitava rezultat konverzije
		WriteLed((adc_result >> 8) & 0x0F);
		TB0CCR3 = (adc_result >> 8) & 0x0F;
		break;
	case  8: break;				// Vector  8: ADC12IFG1
	case 10: break;				// Vector 10: ADC12IFG2
	case 12: break;				// Vector 12: ADC12IFG3
	case 14: break;				// Vector 14: ADC12IFG4
	case 16: break;				// Vector 16: ADC12IFG5
	case 18: break;				// Vector 18: ADC12IFG6
	case 20: break;				// Vector 20: ADC12IFG7
	case 22: break;				// Vector 22: ADC12IFG8
	case 24: break;				// Vector 24: ADC12IFG9
	case 26: break;				// Vector 26: ADC12IFG10
	case 28: break;				// Vector 28: ADC12IFG11
	case 30: break;				// Vector 30: ADC12IFG12
	case 32: break;				// Vector 32: ADC12IFG13
	case 34: break;				// Vector 34: ADC12IFG14
	default: break;
	}
}
